;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Edit existing arcs by dragging radius or direction.
; Use AED for radius change, SED to change "bulge" by dragging direction.
;
; Steve Logan (72260,3530 on CIS)
;
(defun getp (p plist) (cdr (assoc p plist)))
(defun putp (p plist value)
  (if (assoc p plist)
      (subst (cons p value) (assoc p plist) plist)
      (cons (cons p value) plist)
  )
)
(defun c:nxt () (setq en (entnext en) elist (if en (entget en) nil)))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;Routine to allow circles and arcs to be resized (change radius only) by
;picking and dragging.
;
(defun c:aed (/ elist en pick_pt lasten)
  (while (mapcar 'set '(en pick_pt) (entsel"\nChoose arc"))
    (setq elist (entget en)
          lasten (entlast)
    )
    (cond 
          ((member (getp 0 elist) '("ARC" "CIRCLE"))
             (command) 
             (command "scale" en "" (getp 10 elist) 
                      "r" (getp 40 elist) "drag" pause
             )
          )
          (T (princ"\nItem selected is not a CIRCLE or ARC."))
    ) 
  )
  (princ)
)  
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;Routine to adjust center for a selected arc (uses Start,End,Direction)
;Direction is measured from the closest endpoint 
(defun c:sed (/ elist en pick_pt lasten start end temp key)
  (while (mapcar 'set '(en pick_pt) (entsel"\nChoose arc"))
    (setq elist (entget en)
          lasten (entlast)
    )
    (cond 
          ((member (getp 0 elist) '("ARC"));I might add support for Lines & Plines
             (setq start (polar (getp 10 elist) (getp 50 elist)(getp 40 elist))
                   end   (polar (getp 10 elist) (getp 51 elist)(getp 40 elist))
             )
             (if (< (distance pick_pt end) (distance pick_pt start))
                 (mapcar 'set '(start end) (list end start))
             )
             (command) 
             (command "arc" start "E" end "D" "drag" pause )
             (cond ((/= lasten (entlast)) 
                    (setq temp (entget (entlast)))
                    (foreach key '(10 40 50 51) 
                      (setq elist (putp key elist (getp key temp)))
                    )
                    (entdel (entlast))
                    (entmod elist)
                   )
             )
          )
          (T (princ"\nItem selected is not an ARC."))
    ) 
  )
  (princ)
)  

(C:AED)  